<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Hakkında </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Yazar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Bağış</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation type="unfinished">Lisans: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Temizle</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>s</source>
        <translation type="unfinished">sn</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation type="unfinished">Ekle</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Filigran Resmi Gerekli</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Lüffen Filigran Resmini Ayarlar &gt; Seçenekler &gt; Ek Açıklama &gt; Güncelle kısmından ekleyin</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation type="unfinished">Boyama Yollarını Yumuşat</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation type="unfinished">Etkinleştirildiğinde, çizim bittikten sonra 
kalem ve işaretleme yollarını yumuşatır.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation type="unfinished">Yumuşatma Çarpanı</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation type="unfinished">Yumuşatma faktörü artırmak, kalem ve
işaretleyici için hassasiyeti azaltır ancak
daha düzgün hale getirir.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation type="unfinished">Yorumcu Ayarları</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation type="unfinished">Uygulama başlarken varsayılan kipte ekran görüntüsünü yakala</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation type="unfinished">Uygulama Tarzı</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation type="unfinished">GUI&apos;nin görünümünü ve uygulamanın temasını ayarlar.
Değişiklik sonrası Ksnip&apos;in yeniden başlatılması gerekir.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation type="unfinished">Uygulama Ayarları</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation type="unfinished">Yeni kayıtları otomatik olarak kopyala</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation type="unfinished">Pencereleri kullan</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation type="unfinished">Değişiklikler için yeniden başlatma gerekli</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Ksnip tek örnek olarak çalışsın</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Yalnızca tek sekme kullanıldığında, sekme çubuğunu gizle.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation type="unfinished">Katkıcılar:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation type="unfinished">İspanyolca Çeviriler</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation type="unfinished">Hollandaca Çeviriler</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation type="unfinished">Rusça Çeviriler</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation type="unfinished">Norveççe Bokmål Çeviriler</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation type="unfinished">Fransızca Çeviriler</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation type="unfinished">Polanyaca Çeviriler</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Snap &amp; Flatpak Desteği</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation type="unfinished">Uyarı - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Yeni</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Farenizle dikdörtgen bir alan çizin</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Tüm ekranlar dahil tam ekran görüntü yakalama</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Farenin bulunduğu ekranı yakalayın</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Odaklanılan mevcut pencereyi yakala</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Fare imlecinin altında olanı yakala</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation type="unfinished">En son seçilen bölgeyi seç</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>please join our </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> server.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please use </source>
        <translation type="unfinished">Hata raporlaması için lütfen </translation>
    </message>
    <message>
        <source> to report bugs.</source>
        <translation type="unfinished"> sayfasını kullanın.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Also possible, </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Donations are always welcome</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Bağış</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor</source>
        <translation>GitHub Sponsoru Olun</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation type="unfinished">Alan Seçimi</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation type="unfinished">Tam Ekran (Tüm Ekranlar)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation type="unfinished">Geçerli Ekran</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation type="unfinished">Etkin Pencere</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation type="unfinished">İmleç Altındaki Pencere</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation type="unfinished">Yükleme Başarılı</translation>
    </message>
    <message>
        <source>Upload script </source>
        <translation>Yükleme kodu </translation>
    </message>
    <message>
        <source> finished successfully.</source>
        <translation type="unfinished"> başarıyla yüklendi.</translation>
    </message>
    <message>
        <source>Uploaded to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation type="unfinished">geçici resimi kaydederken sorun oluştu</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation type="unfinished">İşlem başlatılamadı, yolu ve yetkileri kontrol edin.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation type="unfinished">İşlem kesintiye uğradı</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation type="unfinished">Zaman aşımı</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation type="unfinished">İşlemi okuma hatası</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation type="unfinished">İşlemi yazma hatası</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation type="unfinished">Web hatası, konsol çıkışını kontrol edin</translation>
    </message>
    <message>
        <source>Unknown process error.</source>
        <translation type="unfinished">Bilinmeyen işlem hatası</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation type="unfinished">Yükleme Başarısız</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation type="unfinished">Kısayolları Aktifleştir</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation type="unfinished">Bütün Ekrani Kaydet</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation type="unfinished">Şuanki Ekrani Kaydet</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Etkin pencereyi yakala</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation type="unfinished">Imlecin Altındaki Ekranı Kaydet</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation type="unfinished">Evrensel Kısayollar</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation type="unfinished">Son Seçimi Kaydet</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Temizle</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation type="unfinished">Ekran görüntüsünde fare imlecini yakala</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation type="unfinished">Ekran görüntüsünde fare imleci
gözükür.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation type="unfinished">Görüntü Yakalayıcı</translation>
    </message>
    <message>
        <source>Force Generic Wayland Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Generic Wayland Screenshots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Imgur Geçmişi</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Zaman Damgası</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Bağlantı</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Bağlantıyı Sil</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation type="unfinished">imgur.com adresine yükleme işlemi tamamlandı!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Yeni belirteç alındı, tekrar yüklenmeye çalışılıyor…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Imgur belirtecinin süresi doldu, yeni belirteç isteniyor…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation type="unfinished">Anonim yüklemeyi zorla</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation type="unfinished">Imgur bağlantısını her zaman panoya kopyala</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation type="unfinished">İstemci Kimliği</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation type="unfinished">İstemci Gizliliği</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation type="unfinished">PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation type="unfinished">Bir belirteçle değiştirilecek olan imgur Pin&apos;ini girin.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation type="unfinished">PIN Al</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation type="unfinished">Belirteç Al</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation type="unfinished">Imgur Geçmişi</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation type="unfinished">Imgur Yükleyici</translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Kullanıcı Adı</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Imgur.com bekleniyor…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Imgur.com belirteci başarıyla güncellendi.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation type="unfinished">Imgur.com belirteç güncelleme hatası.</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation type="unfinished">Yüklenme gerçekleştikten sonra Imgur linkini varsayılan tarayıcı ile aç</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation type="unfinished">Ana Url:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Yeni</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Tetiklemeden sonra saniye cinsinden gecikir
ve ekran görüntüsünü yakalanır.</translation>
    </message>
    <message>
        <source>s</source>
        <translation>sn</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Yakalanan ekran görüntüsünü dosya sistemine kaydet</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Yakalanan ekran görüntüsünü panoya kopyala</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Araçlar</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Geri</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>İleri</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished">Kırp</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation type="unfinished">Yakalanan Ekran Görüntüsünü Kırp</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>Kaydedilmemiş</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Karşıya yükle</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Yazdır</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Yazıcı iletişim kutusunu açar ve görüntü yazdırma seçeneği sunar</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Yazdırma Önizleme</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Resim yönünün değiştirilebileceği Baskı Önizleme iletişim penceresini açar</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Ölçekle</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Düzenle</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Seçenekler</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp)</source>
        <translation>Resim Dosyaları (*.png *.jpg *.bmp)</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Fligran ekle</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>D&amp;osya</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation type="unfinished">Resim gösterilemiyor</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation type="unfinished">Farklı Kaydet...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished">Yapıştır</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation type="unfinished">Gömülü Yapıştır</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Sabitle</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Hedefi Kopyala</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Dizini Aç</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Görünüm</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation type="unfinished">Kaydet</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation type="unfinished">Farklı Kaydet</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Dizini Aç</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished">Kopyala</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Hedefi Kopyala</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation type="unfinished">Yakala</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Kapat</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Diğerlerini Kapat</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tümünü Kapat</translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Successfully renamed image to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to rename image to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation type="unfinished">Farklı Kaydet</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished">Resimler</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation type="unfinished">Tüm Dosyalar</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation type="unfinished">Resim Kaydedildi</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation type="unfinished">Resim Kaydedilemedi</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation type="unfinished">Kayıt edildiği yer</translation>
    </message>
    <message>
        <source>Failed to save image to</source>
        <translation type="unfinished">Resmi konuma kayıt edilemedi</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation type="unfinished">Varsayılan noktaya otomatik olarak kaydet</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation type="unfinished">Kaydedilmemiş değişiklikleri iptal etmeden önce, kaydetmek için uyar</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation type="unfinished">Son kayıt dizinini hatırla</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation type="unfinished">Yakalanan görüntüyü kaydetme konumu ve dosya adı</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Gözat</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Kaydedici Ayarları</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation type="unfinished">Görüntü yakalama kayıt konumu</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Kayıt Kalitesi</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Betik:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Gözat</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation type="unfinished">Yükleyici Kodu</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Karşıya Yükleme Betiği Seç</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Görüntü Yakalayıcı</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur Yükleyici</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Uygulama</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation type="unfinished">Kısayollar</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation type="unfinished">Yükleyici</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation type="unfinished">Yükleyici Kodu</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation type="unfinished">Kaydedici</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation type="unfinished">Etiketler</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation type="unfinished">Seçim yaparken arka alanı dondur</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation type="unfinished">Seçim alanında büyüteç göster</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation type="unfinished">Arkaplan görüntüsüne yakınlaştırma yapan bir 
büyüteç gösterilir. Bu seçenek yalnızca &apos;Seçim 
yaparken arka alanı dondur&apos; etkinken çalışır.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation type="unfinished">Seçim Alanı cetvellerini göster</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation type="unfinished">Seçim yaparken dikey ve yatay cetvellerin
gösterilmesini sağlar.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation type="unfinished">Seçim alanı konumu ve boyut bilgisini göster</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation type="unfinished">Seçim Alanı imleç rengi</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation type="unfinished">Seçim Alanı imleç kalınlığı</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation type="unfinished">Yukarı</translation>
    </message>
    <message>
        <source>Down</source>
        <translation type="unfinished">Aşağı</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation type="unfinished">Varsayılan Etiketi Kullan</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation type="unfinished">Etiket Ayarları</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation type="unfinished">Vektör Resim Dosyalari (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished">Ekle</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Kaldır</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation type="unfinished">Düzenleyici Göster</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation type="unfinished">Pencere Iconu Kullan</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation type="unfinished">Etkinleştirildiğinde, işletim sisteminin pencere yöneticisi destekliyorsa görev çubuğuna bir tepsi simgesi ekleyecektir.
Değişiklik yeniden başlatma gerektirir.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation type="unfinished">Pencereyi küçült</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation type="unfinished">Küçültülmüş durumda başlat</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation type="unfinished">Görev çubuğuna küçült</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation type="unfinished">Düzenleyici Göster</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation type="unfinished">Yakala</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Tray icon notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation type="unfinished">Resmi Seç</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished">Resimler</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation type="unfinished">Tüm Dosyalar</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation type="unfinished">Yükleme Kodu Gerekli</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation type="unfinished">Lütfen yükleme kodu ekleyin &gt; Ayarlar &gt; Yükleme Kodu</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation type="unfinished">Yüklemi Kaydet</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation type="unfinished">Resmi harici konuma yüklemek üzerisiniz, devam etmek istiyormusunuz?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation type="unfinished">Yüklemeden önce onay iste</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation type="unfinished">Yükleyici Türü:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation type="unfinished">Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation type="unfinished">Kod</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation type="unfinished">Yükleyici</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation type="unfinished">Sürüm</translation>
    </message>
    <message>
        <source>Build</source>
        <translation type="unfinished">İnşa</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation type="unfinished">Kullanım:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation type="unfinished">Filigran Resmi</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished">Güncelle</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation type="unfinished">Filigrani Döndür</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation type="unfinished">Etkinleştirildiğinde, filigran 45 derece açıyla eklenecektir.</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
